==> core-0.0.26.tgz: package/src/components/Close/Close.stories.tsx <==
/**
 * File: /src/components/Close/Close.stories.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 24-08-2022 06:33:11
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from "react";
import { action } from "@storybook/addon-actions";
import {
  autoContrastArgType,
  createArgsStory,
  createSxArgs,
  sxArgTypes,
} from "../../../storybook";
import { Box } from "../Box";
import { Close } from "./index";

export default {
  title: "components/buttons/Close",
  component: Close,
  parameters: {
    status: { type: "beta" },
  },
};

export const close = createArgsStory(Close, {
  onPress: action("I was pressed"),
  onLongPress: action("I was long pressed"),
  onPressIn: action("I was pressed in"),
  onPressOut: action("I was pressed out"),
});
close.args = {
  children: "Close",
  autoContrast: undefined,
  ...createSxArgs(),
};
close.argTypes = {
  ...autoContrastArgType,
  ...sxArgTypes,
};

export const withBackground = () => (
  <Box sx={{ bg: "background", p: 4 }}>
    <Close sx={{ color: "primary" }} />
  </Box>
);

==> core-0.1.13.tgz: package/src/components/Close/Close.stories.tsx <==
/**
 * File: /src/components/Close/Close.stories.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 24-08-2022 06:33:11
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from 'react';
import { action } from '@storybook/addon-actions';
import { autoContrastArgType, createArgsStory, createSxArgs, sxArgTypes } from '../../../storybook';
import { Box } from '../Box';
import { Close } from './index';

export default {
  title: 'components/buttons/Close',
  component: Close,
  parameters: {
    status: { type: 'beta' },
  },
};

export const close = createArgsStory(Close, {
  onPress: action('I was pressed'),
  onLongPress: action('I was long pressed'),
  onPressIn: action('I was pressed in'),
  onPressOut: action('I was pressed out'),
});
close.args = {
  children: 'Close',
  autoContrast: undefined,
  ...createSxArgs(),
};
close.argTypes = {
  ...autoContrastArgType,
  ...sxArgTypes,
};

export const withBackground = () => (
  <Box sx={{ bg: 'background', p: 4 }}>
    <Close sx={{ color: 'primary' }} />
  </Box>
);
